# MMIO – MultiModal Integration Object

## Installation

## Usage

## Development
Install [maturin](https://www.maturin.rs/installation)

### Run
`maturin develop && python p.py`

## License

EUPL 1.2 

We have distilled the most crucial license specifics to make your adoption seamless: [see here for details](https://github.com/THCLab/licensing).
